@@ -26,7 +26,7 @@ class logger(object):
     def error(self, msg):
         print(msg)
 
-class y:
+class yt:
     """YT Trash yay"""
     def search(self, term):
         """Searches a term on youtube and returns first link.
@@ -35,7 +35,8 @@ class y:
         one video (for example, extended version, 1hr, 8hrs, 10hrs)
         overtakes the original in search.
         If this happens, you may accidentally download the 10hr version
-        of some music and DoS yourself."""
+        of some music and DoS yourself. If this happens,
+        just delete the .part file in the current directory."""
         try:
             results = YoutubeSearch(f"{term}", max_results=1).to_dict()
             results = results[0]
@@ -172,5 +173,5 @@ class y:
                 
         except NameError as e:
             raise ModuleError("youtube-dl must be installed. Use pip install youtube-dl or pip install beetroot[yt].")
-yt = y()
-del y
+        
+yt = yt()
\ No newline at end of file
